aboutsummaryrefslogtreecommitdiffstats
path: root/ui/app/account-detail.js
diff options
context:
space:
mode:
Diffstat (limited to 'ui/app/account-detail.js')
-rw-r--r--ui/app/account-detail.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/ui/app/account-detail.js b/ui/app/account-detail.js
index 2f412c5be..7a0d5b23b 100644
--- a/ui/app/account-detail.js
+++ b/ui/app/account-detail.js
@@ -99,8 +99,9 @@ AccountDetailScreen.prototype.render = function() {
},
}, [
- // What is shown when not editing:
- h('h2.font-medium.color-forest', identity && identity.name)
+ // What is shown when not editing + edit text:
+ h('label.editing-label',[h('.edit-text','edit')]),
+ h('h2.font-medium.color-forest', {title: 'edit'}, identity && identity.name)
]),
]),